@@ -22,5 +22,5 @@ class FrontpageRecordsSearch(RecordsSearch):
 
         index = "rdmrecords-records"
         default_filter = Q(
-            "query_string", query=(
-                "access.record:public " "AND versions.is_latest:true"))
+            "query_string", query=("access.record:public AND versions.is_latest:true")
+        )
